==> haskell-bifunctors-5.5.4-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-bifunctors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bifunctors
version: 5.5.4
id: bifunctors-5.5.4-7WwIqTZmD1u1261f1rhYbT
key: bifunctors-5.5.4-7WwIqTZmD1u1261f1rhYbT
license: BSD-3-Clause
copyright: Copyright (C) 2008-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/bifunctors/
synopsis: Bifunctors
description:
    Bifunctors.
category: Data, Functors
abi: 79983c1a0e585f0d626191da0d22b7c5
exposed: True
exposed-modules:
    Data.Biapplicative Data.Bifunctor.Biff Data.Bifunctor.Clown
    Data.Bifunctor.Fix Data.Bifunctor.Flip Data.Bifunctor.Functor
    Data.Bifunctor.Join Data.Bifunctor.Joker Data.Bifunctor.Product
    Data.Bifunctor.Sum Data.Bifunctor.TH Data.Bifunctor.Tannen
    Data.Bifunctor.Wrapped
hidden-modules: Data.Bifunctor.TH.Internal Paths_bifunctors
import-dirs: /usr/lib/ghc-8.6.5/site-local/bifunctors-5.5.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/bifunctors-5.5.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/bifunctors-5.5.4
hs-libraries: HSbifunctors-5.5.4-7WwIqTZmD1u1261f1rhYbT
depends:
    base-4.12.0.0 base-orphans-0.8.1-DL3hFxbdUY5XKOIQ4ZUe
    comonad-5.0.4-8UKAvbVXEvJ8FD0FgJJhEO containers-0.6.0.1
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP template-haskell-2.14.0.0
    th-abstraction-0.2.11.0-DAhuCgi08HTBWsDjm9nrOq transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-bifunctors/html/bifunctors.haddock
haddock-html: /usr/share/doc/haskell-bifunctors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bifunctors-5.5.4-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-bifunctors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bifunctors
version: 5.5.4
id: bifunctors-5.5.4-AmD8SUmZfWY8kb6qFlRbbz
key: bifunctors-5.5.4-AmD8SUmZfWY8kb6qFlRbbz
license: BSD-3-Clause
copyright: Copyright (C) 2008-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/bifunctors/
synopsis: Bifunctors
description:
    Bifunctors.
category: Data, Functors
abi: bdfcd68180d92cf0706e78f52dba7697
exposed: True
exposed-modules:
    Data.Biapplicative Data.Bifunctor.Biff Data.Bifunctor.Clown
    Data.Bifunctor.Fix Data.Bifunctor.Flip Data.Bifunctor.Functor
    Data.Bifunctor.Join Data.Bifunctor.Joker Data.Bifunctor.Product
    Data.Bifunctor.Sum Data.Bifunctor.TH Data.Bifunctor.Tannen
    Data.Bifunctor.Wrapped
hidden-modules: Data.Bifunctor.TH.Internal Paths_bifunctors
import-dirs: /usr/lib/ghc-8.6.5/site-local/bifunctors-5.5.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/bifunctors-5.5.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/bifunctors-5.5.4
hs-libraries: HSbifunctors-5.5.4-AmD8SUmZfWY8kb6qFlRbbz
depends:
    base-4.12.0.0 base-orphans-0.8.1-DL3hFxbdUY5XKOIQ4ZUe
    comonad-5.0.5-4jZMLPK948W6C4yBvDor7f containers-0.6.0.1
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP template-haskell-2.14.0.0
    th-abstraction-0.2.11.0-DAhuCgi08HTBWsDjm9nrOq transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-bifunctors/html/bifunctors.haddock
haddock-html: /usr/share/doc/haskell-bifunctors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
